@@ -156,9 +156,14 @@ for my $md ( @mdfiles ) {
     say "updated $pm added pod from $md";
   } else {
       my $mdtext = path($md)->slurp();
+      $mdtext =~ s/(\# ABSTRACT.*)\n//;
+      my $abstract = $1;
       my $pod =  $m2p->markdown_to_pod( markdown => $mdtext );
-      $pod = "=pod\n$pod\n=cut\n";
-      path( "./lib/Vote/$name.pod")->spew($pod) unless $pod =~ /README/;
+      my $versionline = "=head1 VERSION $version";
+warn $versionline;
+      # $pod = "$abstract\n$versionline\n$pod\n$footer";
+      $pod = "$abstract\n\n=pod\n\n$versionline\n$pod\n$footer\n=cut\n";
+      path( "./lib/Vote/$name.pod")->spew($pod);
   }
   for my $pm ( values %pmkeys ) {
     my $pmtext = path($pm)->slurp;
