@@ -17,14 +17,14 @@ use Storable 3.15 'dclone';
 
 no warnings 'experimental';
 
-our $VERSION='0.02402';
+our $VERSION='0.02411';
 
 =head1 NAME
 
 Vote::Count
 
 
-=head1 VERSION 0.02402
+=head1 VERSION 0.02411
 
 =cut
 
@@ -200,7 +200,7 @@ This is also extremely useful to researchers who may want to study multiple meth
 
 =head1 Preview Release
 
-This module is almost ready for production.
+This distribution is almost ready for production, but there may be changes made without notice up to stable release. Before putting it into production you should develop a suite of tests against test data. This will warn you of future changes that will break your code, so you can either update or freeze to an earlier version on BackPAN.
 
 
 =head1 Overview
@@ -638,18 +638,26 @@ If you're looking at all of this wondering "which method I should recommend to m
 
 I<Instant Runoff Voting> is simple, easy to count by hand, Later Harm protected, and is the most widely used method. It has serious consistency issues, especially how poorly it handles common cloning situations.
 
-I<Benham Condorcet IRV>, meets the two main Condorcet Criteria, and is countable by hand, but it loses Later Harm.
+I<Benham Condorcet IRV>, meets the two main Condorcet Criteria, and is countable by hand, but it fails Later Harm.
 
-If you like I<Borda> or prefer a I<Range Ballot>, my pick is for I<STAR>. STAR specifies a Range Ballot. Range Ballots are not presently implemented, and will require a lot of work, so it may be some time before it's available here. In the meantime you can implement the RCV variant of STAR with Vote::Count.
+Benham and IRV are good choices for Hand Count Methods.
 
-I<SmithSet IRV>, is the B<best simple method>. It meets all three key criteria for Condorcet Methods and has less Later Harm effect than any other (non-redacting) Condorcet Method.
+I<Smith Set IRV> meets all three key criteria for Condorcet Methods and has less Later Harm effect than any other (non-redacting) Condorcet Method. It is simple to understand, but not practical for hand counting.
 
-I<Redacting Condorcet Methods> are the B<best>. If a Condorcet Winner does not create a Later Harm violation they will always be chosen. They can create a gauge of the later harm effect that then allows for the establishment of a Later Harm tolerance. If there is a Later Harm violation, then ballots are redacted, and the resulting final ballots will meet the Condorcet Criteria.
+If you like I<Borda> or prefer a I<Range Ballot>, my pick is for I<STAR>.
+
+STAR is handcountable but requires a Range Ballot. Range methods like STAR have considerably less Later Harm effect than other Borda Methods.
+
+I<Redacting Condorcet Methods> are the B<best> for a conventional Ranked Choice Ballot. If a Condorcet Winner does not create a Later Harm violation they will always be chosen. They can create a gauge of the later harm effect that then allows for the establishment of a Later Harm tolerance. The steps for I<Condorcet Vs IRV> are easy to understand but the number of steps qualifies it as somewhat complex. Other methods in the family (not yet implemented) will be more complex.
+
+B<STAR> and B<Redacting Condorcet> (Condorcet Vs IRV being the only one available here at the moment) are my preference. If you need to hand count, Benham is your Condorcet Method and IRV is your Later Harm Protected Method. Smith Set IRV is a middle ground. If Later Harm compliance is required a Redacting Condorcet Method is your best choice, and IRV your choice if they're too complex.
 
 
-=head2 Always Pick a Floor Rule
+=head2 Floor Rules and Tie Breakers
 
-In real world elections it is typical to have a number of choices that recieve very little support. A floor rule allows quick elimination of these choices. In cases where voters rank all choices or with single round systems where weak choices have no influence there is no benefit to scoring.
+In real world elections it is typical to have a number of choices that recieve very little support. A Floor Rule allows quick elimination of these choices, but don't help when voters rank all choices. STAR is an exception and does not benefit from a Floor Rule. 5% Approval is a good weak Floor, and TCA is a good aggressive one.
+
+Ties are inescapable. Modified Grand Junction has the maximum resolvability, but has a Later Harm effect. For a Later Harm safe Tie Breaker Eliminate All is effective (except at the final step).
 
 =cut
 
